@@ -714,7 +714,7 @@ class KeycloakAdmin:
         data_raw = self.connection.raw_get(URL_ADMIN_CLIENT_AUTHZ_RESOURCES.format(**params_path), **query)
         return raise_error_from_response(data_raw, KeycloakGetError)
 
-    def create_client_authz_resource(self, client_id, payload):
+    def create_client_authz_resource(self, client_id, payload, skip_exists=False):
         """
         Create a resource set.
         :param client_id: id in ClientRepresentation
@@ -726,7 +726,7 @@ class KeycloakAdmin:
         params_path = {"realm-name": self.realm_name, "id": client_id}
         data_raw = self.connection.raw_post(URL_ADMIN_CLIENT_AUTHZ_RESOURCES.format(**params_path),
                                             data=json.dumps(payload, default=serialize))
-        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=201)
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=201, skip_exists=skip_exists)
 
     def update_client_authz_resource(self, client_id, resource_id, payload):
         """
@@ -759,7 +759,7 @@ class KeycloakAdmin:
         data_raw = self.connection.raw_delete(URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID.format(**params_path))
         return raise_error_from_response(data_raw, KeycloakGetError, expected_code=204)
 
-    def create_client_authz_policy(self, client_id, payload, policy_type='role'):
+    def create_client_authz_policy(self, client_id, payload, policy_type='role', skip_exists=False):
         """
         Create a policy.
         :param client_id: id in ClientRepresentation
@@ -772,7 +772,7 @@ class KeycloakAdmin:
         params_path = {"realm-name": self.realm_name, "id": client_id, "policy-type": policy_type}
         data_raw = self.connection.raw_post(URL_ADMIN_CLIENT_AUTHZ_POLICIES.format(**params_path),
                                             data=json.dumps(payload))
-        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=201)
+        return raise_error_from_response(data_raw, KeycloakGetError, expected_code=201, skip_exists=skip_exists)
 
     def update_client_authz_policy(self, client_id, policy_id, payload, policy_type='role'):
         """
